/*
 * Copyright (c) 2013 The Cat Hive Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.cathive.fonts.fontawesome;

/**
 * This class contains String constants that represent the different FontAwesome
 * characters that can be used.
 * <p>Source: https://raw.github.com/FortAwesome/Font-Awesome/v3.2.1/src/icons.yml</p>
 * @author Benjamin P. Jung
 */
public final class FontAwesome {

    /**
     * Music
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_MUSIC = '\uf001';

    /**
     * Search
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SEARCH = '\uf002';

    /**
     * Glass
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_GLASS = '\uf000';

    /**
     * Envelope Alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ENVELOPE_ALT = '\uf003';

    /**
     * Heart
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_HEART = '\uf004';

    /**
     * Star
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_STAR = '\uf005';

    /**
     * Star Empty
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_STAR_EMPTY = '\uf006';

    /**
     * User
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_USER = '\uf007';

    /**
     * Film
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FILM = '\uf008';

    /**
     * th-large
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TH_LARGE = '\uf009';

    /**
     * th
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TH = '\uf00a';

    /**
     * th-list
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TH_LIST = '\uf00b';

    /**
     * OK
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_OK = '\uf00c';

    /**
     * Remove
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_REMOVE = '\uf00d';

    /**
     * Zoom In
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ZOOM_IN = '\uf00e';

    /**
     * Zoom Out
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ZOOM_OUT = '\uf010';

    /**
     * Off
     * <p>aliases:</p>
     * <ul>
     *   <li>power-off</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_OFF = '\uf011';

    /**
     * signal
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SIGNAL = '\uf012';

    /**
     * cog
     * <p>aliases:</p>
     * <ul>
     *   <li>gear</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_COG = '\uf013';

    /**
     * trash
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TRASH = '\uf014';

    /**
     * home
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_HOME = '\uf015';

    /**
     * file-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FILE_ALT = '\uf016';

    /**
     * time
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TIME = '\uf017';

    /**
     * road
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ROAD = '\uf018';

    /**
     * download-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_DOWNLOAD_ALT = '\uf019';

    /**
     * download
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_DOWNLOAD = '\uf01a';

    /**
     * upload
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_UPLOAD = '\uf01b';

    /**
     * inbox
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_INBOX = '\uf01c';

    /**
     * play-circle
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PLAY_CIRCLE = '\uf01d';

    /**
     * repeat
     * <p>aliases:</p>
     * <ul>
     *   <li>rotate-right</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_REPEAT = '\uf01e';

    /**
     * refresh
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_REFRESH = '\uf021';

    /**
     * list-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_LIST_ALT = '\uf022';

    /**
     * lock
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_LOCK = '\uf023';

    /**
     * flag
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FLAG = '\uf024';

    /**
     * headphones
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_HEADPHONES = '\uf025';

    /**
     * volume-off
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_VOLUME_OFF = '\uf026';

    /**
     * volume-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_VOLUME_DOWN = '\uf027';

    /**
     * volume-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_VOLUME_UP = '\uf028';

    /**
     * qrcode
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_QRCODE = '\uf029';

    /**
     * barcode
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BARCODE = '\uf02a';

    /**
     * tag
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TAG = '\uf02b';

    /**
     * tags
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TAGS = '\uf02c';

    /**
     * book
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BOOK = '\uf02d';

    /**
     * bookmark
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BOOKMARK = '\uf02e';

    /**
     * print
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PRINT = '\uf02f';

    /**
     * camera
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CAMERA = '\uf030';

    /**
     * font
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FONT = '\uf031';

    /**
     * bold
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BOLD = '\uf032';

    /**
     * italic
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ITALIC = '\uf033';

    /**
     * text-height
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TEXT_HEIGHT = '\uf034';

    /**
     * text-width
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TEXT_WIDTH = '\uf035';

    /**
     * align-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ALIGN_LEFT = '\uf036';

    /**
     * align-center
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ALIGN_CENTER = '\uf037';

    /**
     * align-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ALIGN_RIGHT = '\uf038';

    /**
     * align-justify
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ALIGN_JUSTIFY = '\uf039';

    /**
     * list
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_LIST = '\uf03a';

    /**
     * indent-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_INDENT_LEFT = '\uf03b';

    /**
     * indent-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_INDENT_RIGHT = '\uf03c';

    /**
     * facetime-video
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FACETIME_VIDEO = '\uf03d';

    /**
     * picture
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PICTURE = '\uf03e';

    /**
     * pencil
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PENCIL = '\uf040';

    /**
     * map-marker
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_MAP_MARKER = '\uf041';

    /**
     * adjust
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ADJUST = '\uf042';

    /**
     * tint
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TINT = '\uf043';

    /**
     * edit
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_EDIT = '\uf044';

    /**
     * share
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SHARE = '\uf045';

    /**
     * check
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CHECK = '\uf046';

    /**
     * move
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_MOVE = '\uf047';

    /**
     * step-backward
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_STEP_BACKWARD = '\uf048';

    /**
     * fast-backward
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FAST_BACKWARD = '\uf049';

    /**
     * backward
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BACKWARD = '\uf04a';

    /**
     * play
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PLAY = '\uf04b';

    /**
     * pause
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PAUSE = '\uf04c';

    /**
     * stop
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_STOP = '\uf04d';

    /**
     * forward
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FORWARD = '\uf04e';

    /**
     * fast-forward
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FAST_FORWARD = '\uf050';

    /**
     * step-forward
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_STEP_FORWARD = '\uf051';

    /**
     * eject
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_EJECT = '\uf052';

    /**
     * chevron-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CHEVRON_LEFT = '\uf053';

    /**
     * chevron-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CHEVRON_RIGHT = '\uf054';

    /**
     * plus-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PLUS_SIGN = '\uf055';

    /**
     * minus-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_MINUS_SIGN = '\uf056';

    /**
     * remove-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_REMOVE_SIGN = '\uf057';

    /**
     * ok-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_OK_SIGN = '\uf058';

    /**
     * question-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_QUESTION_SIGN = '\uf059';

    /**
     * info-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_INFO_SIGN = '\uf05a';

    /**
     * screenshot
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SCREENSHOT = '\uf05b';

    /**
     * remove-circle
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_REMOVE_CIRCLE = '\uf05c';

    /**
     * ok-circle
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_OK_CIRCLE = '\uf05d';

    /**
     * ban-circle
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BAN_CIRCLE = '\uf05e';

    /**
     * arrow-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ARROW_LEFT = '\uf060';

    /**
     * arrow-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ARROW_RIGHT = '\uf061';

    /**
     * arrow-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ARROW_UP = '\uf062';

    /**
     * arrow-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ARROW_DOWN = '\uf063';

    /**
     * share-alt
     * <p>aliases:</p>
     * <ul>
     *   <li>mail-forward</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SHARE_ALT = '\uf064';

    /**
     * resize-full
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_RESIZE_FULL = '\uf065';

    /**
     * resize-small
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_RESIZE_SMALL = '\uf066';

    /**
     * plus
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PLUS = '\uf067';

    /**
     * minus
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_MINUS = '\uf068';

    /**
     * asterisk
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_ASTERISK = '\uf069';

    /**
     * exclamation-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_EXCLAMATION_SIGN = '\uf06a';

    /**
     * gift
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_GIFT = '\uf06b';

    /**
     * leaf
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_LEAF = '\uf06c';

    /**
     * fire
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FIRE = '\uf06d';

    /**
     * eye-open
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_EYE_OPEN = '\uf06e';

    /**
     * eye-close
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_EYE_CLOSE = '\uf070';

    /**
     * warning-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_WARNING_SIGN = '\uf071';

    /**
     * plane
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PLANE = '\uf072';

    /**
     * calendar
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CALENDAR = '\uf073';

    /**
     * random
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_RANDOM = '\uf074';

    /**
     * comment
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_COMMENT = '\uf075';

    /**
     * magnet
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_MAGNET = '\uf076';

    /**
     * chevron-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CHEVRON_UP = '\uf077';

    /**
     * chevron-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CHEVRON_DOWN = '\uf078';

    /**
     * retweet
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_RETWEET = '\uf079';

    /**
     * shopping-cart
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SHOPPING_CART = '\uf07a';

    /**
     * folder-close
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FOLDER_CLOSE = '\uf07b';

    /**
     * folder-open
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FOLDER_OPEN = '\uf07c';

    /**
     * resize-vertical
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_RESIZE_VERTICAL = '\uf07d';

    /**
     * resize-horizontal
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_RESIZE_HORIZONTAL = '\uf07e';

    /**
     * bar-chart
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_BAR_CHART = '\uf080';

    /**
     * twitter-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TWITTER_SIGN = '\uf081';

    /**
     * facebook-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_FACEBOOK_SIGN = '\uf082';

    /**
     * camera-retro
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_CAMERA_RETRO = '\uf083';

    /**
     * key
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_KEY = '\uf084';

    /**
     * cogs
     * <p>aliases:</p>
     * <ul>
     *   <li>gears</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_COGS = '\uf085';

    /**
     * comments
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_COMMENTS = '\uf086';

    /**
     * thumbs-up-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_THUMBS_UP_ALT = '\uf087';

    /**
     * thumbs-down-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_THUMBS_DOWN_ALT = '\uf088';

    /**
     * star-half
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_STAR_HALF = '\uf089';

    /**
     * heart-empty
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_HEART_EMPTY = '\uf08a';

    /**
     * signout
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SIGNOUT = '\uf08b';

    /**
     * linkedin-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_LINKEDIN_SIGN = '\uf08c';

    /**
     * pushpin
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_PUSHPIN = '\uf08d';

    /**
     * external-link
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_EXTERNAL_LINK = '\uf08e';

    /**
     * signin
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_SIGNIN = '\uf090';

    /**
     * trophy
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_TROPHY = '\uf091';

    /**
     * github-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_GITHUB_SIGN = '\uf092';

    /**
     * upload-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_UPLOAD_ALT = '\uf093';

    /**
     * lemon
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 1.0
     */
    public static final char ICON_LEMON = '\uf094';

    /**
     * phone
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_PHONE = '\uf095';

    /**
     * check-empty
     * <p>aliases:</p>
     * <ul>
     *   <li>unchecked</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CHECK_EMPTY = '\uf096';

    /**
     * bookmark-empty
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_BOOKMARK_EMPTY = '\uf097';

    /**
     * phone-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_PHONE_SIGN = '\uf098';

    /**
     * twitter
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_TWITTER = '\uf099';

    /**
     * facebook
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_FACEBOOK = '\uf09a';

    /**
     * github
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_GITHUB = '\uf09b';

    /**
     * unlock
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_UNLOCK = '\uf09c';

    /**
     * credit-card
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CREDIT_CARD = '\uf09d';

    /**
     * rss
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_RSS = '\uf09e';

    /**
     * hdd
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_HDD = '\uf0a0';

    /**
     * bullhorn
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_BULLHORN = '\uf0a1';

    /**
     * bell
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_BELL = '\uf0a2';

    /**
     * certificate
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CERTIFICATE = '\uf0a3';

    /**
     * hand-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_HAND_RIGHT = '\uf0a4';

    /**
     * hand-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_HAND_LEFT = '\uf0a5';

    /**
     * hand-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_HAND_UP = '\uf0a6';

    /**
     * hand-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_HAND_DOWN = '\uf0a7';

    /**
     * circle-arrow-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CIRCLE_ARROW_LEFT = '\uf0a8';

    /**
     * circle-arrow-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CIRCLE_ARROW_RIGHT = '\uf0a9';

    /**
     * circle-arrow-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CIRCLE_ARROW_UP = '\uf0aa';

    /**
     * circle-arrow-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CIRCLE_ARROW_DOWN = '\uf0ab';

    /**
     * globe
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_GLOBE = '\uf0ac';

    /**
     * wrench
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_WRENCH = '\uf0ad';

    /**
     * tasks
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_TASKS = '\uf0ae';

    /**
     * filter
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_FILTER = '\uf0b0';

    /**
     * briefcase
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_BRIEFCASE = '\uf0b1';

    /**
     * fullscreen
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_FULLSCREEN = '\uf0b2';

    /**
     * group
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_GROUP = '\uf0c0';

    /**
     * link
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_LINK = '\uf0c1';

    /**
     * cloud
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CLOUD = '\uf0c2';

    /**
     * beaker
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_BEAKER = '\uf0c3';

    /**
     * cut
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CUT = '\uf0c4';

    /**
     * copy
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_COPY = '\uf0c5';

    /**
     * paper-clip
     * <p>aliases:</p>
     * <ul>
     *   <li>paperclip</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_PAPER_CLIP = '\uf0c6';

    /**
     * save
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_SAVE = '\uf0c7';

    /**
     * sign-blank
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_SIGN_BLANK = '\uf0c8';

    /**
     * reorder
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_REORDER = '\uf0c9';

    /**
     * list-ul
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_LIST_UL = '\uf0ca';

    /**
     * list-ol
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_LIST_OL = '\uf0cb';

    /**
     * strikethrough
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_STRIKETHROUGH = '\uf0cc';

    /**
     * underline
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_UNDERLINE = '\uf0cd';

    /**
     * table
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_TABLE = '\uf0ce';

    /**
     * magic
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_MAGIC = '\uf0d0';

    /**
     * truck
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_TRUCK = '\uf0d1';

    /**
     * pinterest
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_PINTEREST = '\uf0d2';

    /**
     * pinterest-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_PINTEREST_SIGN = '\uf0d3';

    /**
     * google-plus-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_GOOGLE_PLUS_SIGN = '\uf0d4';

    /**
     * google-plus
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_GOOGLE_PLUS = '\uf0d5';

    /**
     * money
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_MONEY = '\uf0d6';

    /**
     * caret-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CARET_DOWN = '\uf0d7';

    /**
     * caret-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CARET_UP = '\uf0d8';

    /**
     * caret-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CARET_LEFT = '\uf0d9';

    /**
     * caret-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_CARET_RIGHT = '\uf0da';

    /**
     * columns
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_COLUMNS = '\uf0db';

    /**
     * sort
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_SORT = '\uf0dc';

    /**
     * sort-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_SORT_DOWN = '\uf0dd';

    /**
     * sort-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_SORT_UP = '\uf0de';

    /**
     * Envelope
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_ENVELOPE = '\uf0e0';

    /**
     * linkedin
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_LINKEDIN = '\uf0e1';

    /**
     * undo
     * <p>aliases:</p>
     * <ul>
     *   <li>rotate-left</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_UNDO = '\uf0e2';

    /**
     * legal
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_LEGAL = '\uf0e3';

    /**
     * dashboard
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_DASHBOARD = '\uf0e4';

    /**
     * comment-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_COMMENT_ALT = '\uf0e5';

    /**
     * comments-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_COMMENTS_ALT = '\uf0e6';

    /**
     * bolt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_BOLT = '\uf0e7';

    /**
     * sitemap
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_SITEMAP = '\uf0e8';

    /**
     * umbrella
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_UMBRELLA = '\uf0e9';

    /**
     * paste
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_PASTE = '\uf0ea';

    /**
     * lightbulb
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_LIGHTBULB = '\uf0eb';

    /**
     * exchange
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_EXCHANGE = '\uf0ec';

    /**
     * cloud-download
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_CLOUD_DOWNLOAD = '\uf0ed';

    /**
     * cloud-upload
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_CLOUD_UPLOAD = '\uf0ee';

    /**
     * user-md
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     * </ul>
     * @since 2.0
     */
    public static final char ICON_USER_MD = '\uf0f0';

    /**
     * stethoscope
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_STETHOSCOPE = '\uf0f1';

    /**
     * suitcase
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_SUITCASE = '\uf0f2';

    /**
     * bell-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_BELL_ALT = '\uf0f3';

    /**
     * coffee
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_COFFEE = '\uf0f4';

    /**
     * food
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_FOOD = '\uf0f5';

    /**
     * file-text-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_FILE_TEXT_ALT = '\uf0f6';

    /**
     * building
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_BUILDING = '\uf0f7';

    /**
     * hospital
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_HOSPITAL = '\uf0f8';

    /**
     * ambulance
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_AMBULANCE = '\uf0f9';

    /**
     * medkit
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_MEDKIT = '\uf0fa';

    /**
     * fighter-jet
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_FIGHTER_JET = '\uf0fb';

    /**
     * beer
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_BEER = '\uf0fc';

    /**
     * h-sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_H_SIGN = '\uf0fd';

    /**
     * plus-sign-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Medical Icons</li>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_PLUS_SIGN_ALT = '\uf0fe';

    /**
     * double-angle-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_DOUBLE_ANGLE_LEFT = '\uf100';

    /**
     * double-angle-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_DOUBLE_ANGLE_RIGHT = '\uf101';

    /**
     * double-angle-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_DOUBLE_ANGLE_UP = '\uf102';

    /**
     * double-angle-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_DOUBLE_ANGLE_DOWN = '\uf103';

    /**
     * angle-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_ANGLE_LEFT = '\uf104';

    /**
     * angle-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_ANGLE_RIGHT = '\uf105';

    /**
     * angle-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_ANGLE_UP = '\uf106';

    /**
     * angle-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_ANGLE_DOWN = '\uf107';

    /**
     * desktop
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_DESKTOP = '\uf108';

    /**
     * laptop
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_LAPTOP = '\uf109';

    /**
     * tablet
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_TABLET = '\uf10a';

    /**
     * mobile-phone
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_MOBILE_PHONE = '\uf10b';

    /**
     * circle-blank
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_CIRCLE_BLANK = '\uf10c';

    /**
     * quote-left
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_QUOTE_LEFT = '\uf10d';

    /**
     * quote-right
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_QUOTE_RIGHT = '\uf10e';

    /**
     * spinner
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_SPINNER = '\uf110';

    /**
     * circle
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_CIRCLE = '\uf111';

    /**
     * reply
     * <p>aliases:</p>
     * <ul>
     *   <li>mail-reply</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_REPLY = '\uf112';

    /**
     * github-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_GITHUB_ALT = '\uf113';

    /**
     * folder-close-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_FOLDER_CLOSE_ALT = '\uf114';

    /**
     * folder-open-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.0
     */
    public static final char ICON_FOLDER_OPEN_ALT = '\uf115';

    /**
     * expand-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_EXPAND_ALT = '\uf116';

    /**
     * collapse-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_COLLAPSE_ALT = '\uf117';

    /**
     * smile
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_SMILE = '\uf118';

    /**
     * frown
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_FROWN = '\uf119';

    /**
     * meh
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_MEH = '\uf11a';

    /**
     * gamepad
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_GAMEPAD = '\uf11b';

    /**
     * keyboard
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_KEYBOARD = '\uf11c';

    /**
     * flag-alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_FLAG_ALT = '\uf11d';

    /**
     * flag-checkered
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_FLAG_CHECKERED = '\uf11e';

    /**
     * terminal
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_TERMINAL = '\uf120';

    /**
     * code
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CODE = '\uf121';

    /**
     * reply-all
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_REPLY_ALL = '\uf122';

    /**
     * mail-reply-all
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_MAIL_REPLY_ALL = '\uf122';

    /**
     * star-half-empty
     * <p>aliases:</p>
     * <ul>
     *   <li>star-half-full</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_STAR_HALF_EMPTY = '\uf123';

    /**
     * location-arrow
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_LOCATION_ARROW = '\uf124';

    /**
     * crop
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CROP = '\uf125';

    /**
     * code-fork
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CODE_FORK = '\uf126';

    /**
     * unlink
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_UNLINK = '\uf127';

    /**
     * question
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_QUESTION = '\uf128';

    /**
     * info
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_INFO = '\uf129';

    /**
     * exclamation
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_EXCLAMATION = '\uf12a';

    /**
     * superscript
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_SUPERSCRIPT = '\uf12b';

    /**
     * subscript
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_SUBSCRIPT = '\uf12c';

    /**
     * eraser
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_ERASER = '\uf12d';

    /**
     * puzzle-piece
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_PUZZLE_PIECE = '\uf12e';

    /**
     * microphone
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_MICROPHONE = '\uf130';

    /**
     * microphone-off
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_MICROPHONE_OFF = '\uf131';

    /**
     * shield
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_SHIELD = '\uf132';

    /**
     * calendar-empty
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CALENDAR_EMPTY = '\uf133';

    /**
     * fire-extinguisher
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_FIRE_EXTINGUISHER = '\uf134';

    /**
     * rocket
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_ROCKET = '\uf135';

    /**
     * MaxCDN
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_MAXCDN = '\uf136';

    /**
     * Chevron Sign Left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CHEVRON_SIGN_LEFT = '\uf137';

    /**
     * Chevron Sign Right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CHEVRON_SIGN_RIGHT = '\uf138';

    /**
     * Chevron Sign Up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CHEVRON_SIGN_UP = '\uf139';

    /**
     * Chevron Sign Down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CHEVRON_SIGN_DOWN = '\uf13a';

    /**
     * HTML 5 Logo
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_HTML5 = '\uf13b';

    /**
     * CSS 3 Logo
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CSS3 = '\uf13c';

    /**
     * Anchor
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_ANCHOR = '\uf13d';

    /**
     * Unlock Alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_UNLOCK_ALT = '\uf13e';

    /**
     * Bullseye
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_BULLSEYE = '\uf140';

    /**
     * Horizontal Ellipsis
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_ELLIPSIS_HORIZONTAL = '\uf141';

    /**
     * Vertical Ellipsis
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_ELLIPSIS_VERTICAL = '\uf142';

    /**
     * RSS Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_RSS_SIGN = '\uf143';

    /**
     * Play Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_PLAY_SIGN = '\uf144';

    /**
     * Ticket
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_TICKET = '\uf145';

    /**
     * Minus Sign Alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_MINUS_SIGN_ALT = '\uf146';

    /**
     * Check Minus
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CHECK_MINUS = '\uf147';

    /**
     * Level Up
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_LEVEL_UP = '\uf148';

    /**
     * Level Down
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_LEVEL_DOWN = '\uf149';

    /**
     * Check Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_CHECK_SIGN = '\uf14a';

    /**
     * Edit Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_EDIT_SIGN = '\uf14b';

    /**
     * Exteral Link Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_EXTERNAL_LINK_SIGN = '\uf14c';

    /**
     * Share Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.1
     */
    public static final char ICON_SHARE_SIGN = '\uf14d';

    /**
     * Compass
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_COMPASS = '\uf14e';

    /**
     * Collapse
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_COLLAPSE = '\uf150';

    /**
     * Collapse Top
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_COLLAPSE_TOP = '\uf151';

    /**
     * Expand
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_EXPAND = '\uf152';

    /**
     * Euro (EUR)
     * <p>aliases:</p>
     * <ul>
     *   <li>euro</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_EUR = '\uf153';

    /**
     * GBP
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_GBP = '\uf154';

    /**
     * US Dollar
     * <p>aliases:</p>
     * <ul>
     *   <li>dollar</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_USD = '\uf155';

    /**
     * Indian Rupee (INR)
     * <p>aliases:</p>
     * <ul>
     *   <li>rupee</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_INR = '\uf156';

    /**
     * Japanese Yen (JPY)
     * <p>aliases:</p>
     * <ul>
     *   <li>yen</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_JPY = '\uf157';

    /**
     * Renminbi (CNY)
     * <p>aliases:</p>
     * <ul>
     *   <li>renminbi</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_CNY = '\uf158';

    /**
     * Korean Won (KRW)
     * <p>aliases:</p>
     * <ul>
     *   <li>won</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_KRW = '\uf159';

    /**
     * Bitcoin (BTC)
     * <p>aliases:</p>
     * <ul>
     *   <li>bitcoin</li>
     * </ul>
     * <p>Categories:</p>
     * <ul>
     *   <li>Currency Icons</li>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_BTC = '\uf15a';

    /**
     * File
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_FILE = '\uf15b';

    /**
     * File Text
     * <p>Categories:</p>
     * <ul>
     *   <li>Text Editor Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_FILE_TEXT = '\uf15c';

    /**
     * Sort By Alphabet
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SORT_BY_ALPHABET = '\uf15d';

    /**
     * Sort By Alphabet Alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SORT_BY_ALPHABET_ALT = '\uf15e';

    /**
     * Sort By Attributes
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SORT_BY_ATTRIBUTES = '\uf160';

    /**
     * Sort By Attributes Alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SORT_BY_ATTRIBUTES_ALT = '\uf161';

    /**
     * Sort By Order
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SORT_BY_ORDER = '\uf162';

    /**
     * Sort By Order Alt
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SORT_BY_ORDER_ALT = '\uf163';

    /**
     * thumbs-up
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_THUMBS_UP = '\uf164';

    /**
     * thumbs-down
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_THUMBS_DOWN = '\uf165';

    /**
     * YouTube Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_YOUTUBE_SIGN = '\uf166';

    /**
     * YouTube
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_YOUTUBE = '\uf167';

    /**
     * Xing
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_XING = '\uf168';

    /**
     * Xing Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_XING_SIGN = '\uf169';

    /**
     * YouTube Play
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     *   <li>Video Player Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_YOUTUBE_PLAY = '\uf16a';

    /**
     * Dropbox
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_DROPBOX = '\uf16b';

    /**
     * Stack Exchange
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_STACKEXCHANGE = '\uf16c';

    /**
     * Instagram
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_INSTAGRAM = '\uf16d';

    /**
     * Flickr
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_FLICKR = '\uf16e';

    /**
     * App.net
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_ADN = '\uf170';

    /**
     * Bitbucket
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_BITBUCKET = '\uf171';

    /**
     * Bitbucket Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_BITBUCKET_SIGN = '\uf172';

    /**
     * Tumblr
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_TUMBLR = '\uf173';

    /**
     * Tumblr Sign
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_TUMBLR_SIGN = '\uf174';

    /**
     * Long Arrow Down
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_LONG_ARROW_DOWN = '\uf175';

    /**
     * Long Arrow Up
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_LONG_ARROW_UP = '\uf176';

    /**
     * Long Arrow Left
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_LONG_ARROW_LEFT = '\uf177';

    /**
     * Long Arrow Right
     * <p>Categories:</p>
     * <ul>
     *   <li>Directional Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_LONG_ARROW_RIGHT = '\uf178';

    /**
     * Apple
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_APPLE = '\uf179';

    /**
     * Windows
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_WINDOWS = '\uf17a';

    /**
     * Android
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_ANDROID = '\uf17b';

    /**
     * Linux
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_LINUX = '\uf17c';

    /**
     * Dribbble
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_DRIBBBLE = '\uf17d';

    /**
     * Skype
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SKYPE = '\uf17e';

    /**
     * Foursquare
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_FOURSQUARE = '\uf180';

    /**
     * Trello
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_TRELLO = '\uf181';

    /**
     * Female
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_FEMALE = '\uf182';

    /**
     * Male
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_MALE = '\uf183';

    /**
     * Gittip
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_GITTIP = '\uf184';

    /**
     * Sun
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_SUN = '\uf185';

    /**
     * Moon
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_MOON = '\uf186';

    /**
     * Archive
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_ARCHIVE = '\uf187';

    /**
     * Bug
     * <p>Categories:</p>
     * <ul>
     *   <li>Web Application Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_BUG = '\uf188';

    /**
     * VK
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_VK = '\uf189';

    /**
     * Weibo
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_WEIBO = '\uf18a';

    /**
     * Renren
     * <p>Categories:</p>
     * <ul>
     *   <li>Brand Icons</li>
     * </ul>
     * @since 3.2
     */
    public static final char ICON_RENREN = '\uf18b';


    // Private c-tor to prevent construction of this helper class.
    private FontAwesome() {
        throw new IllegalStateException("Helper class is not ment to be constructed.");
    }

}
